"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var vue_1 = require("@hyral/vue");
var Fallback_1 = __importDefault(require("./Components/Fallback"));
/**
 * Uses Hyral ResourceMixin to fetch the required drupal data automatically
 */
exports.default = {
    mixins: [vue_1.ResourceMixin],
    props: {
        uuid: {
            type: String,
            required: false,
        },
        type: {
            type: String,
            required: false,
        },
    },
    data: function () {
        var self = this;
        var route = self.$store.state.druxtRouter.route;
        // Converts props and / or druxtrouterstate into input for the @hyral/vue mixin
        return {
            id: self.uuid || route.props.uuid,
            resourceType: self.type || route.props.type,
            hyralService: 'drupal',
        };
    },
    methods: {
        /**
         * Returns the component from the mapping according to the name of the component type
         *
         * @requires this.mapping Throws error if this.mapping is not present
         * @see this.mapping.fallback Returns renderless fallback component if name not found and mapping.fallback is not present
         */
        getEntity: function (name) {
            var self = this;
            if (!self.mapping) {
                throw new Error('No computed mapping found');
            }
            if (!(name in self.mapping)) {
                return self.mapping.fallback ? self.mapping.fallback : Fallback_1.default;
            }
            return self.mapping[name];
        },
    },
};
