"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateMapping = exports.validateBaseUrl = exports.validateOptions = void 0;
/**
 * Checks the validity of the options
 */
var validateOptions = function (options) {
    if (!options)
        throw new Error('DrupalNuxtPlugin requires options as a parameter');
};
exports.validateOptions = validateOptions;
/**
 * Checks the validity of the baseUrl
 */
var validateBaseUrl = function (options) {
    if (!options.baseUrl)
        throw new Error('DrupalNuxtPlugin requires a baseUrl in options');
};
exports.validateBaseUrl = validateBaseUrl;
/**
 * Checks the validity of the mapping.
 *
 * IMapping: { nodes: [], menus: [], entities: {}}
 */
var validateMapping = function (options) {
    var mapping = options.mapping;
    if (!mapping) {
        throw new Error('DrupalNuxtPlugin requires a mapping in options');
    }
    if (!mapping.entities || !mapping.menus || !mapping.nodes) {
        throw new Error('DrupalNuxtPlugin requires a nodes, menus and entities attribute');
    }
    if (!Array.isArray(mapping.nodes) || !Array.isArray(mapping.menus)) {
        throw new Error('DrupalNuxtPlugin requires nodes and menus as array');
    }
    if (Array.isArray(mapping.entities)) {
        throw new Error('DrupalNuxtPlugin requires entities to be a record');
    }
};
exports.validateMapping = validateMapping;
