"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Repository_1 = __importDefault(require("./Repository"));
var createRepositoryManager = function () {
    var repositories = {};
    /**
     * Will ensure no repositories of duplicate resourceType are created
     */
    function addRepository(repository) {
        if (typeof repositories[repository.resourceType] === 'undefined') {
            repositories[repository.resourceType] = repository;
        }
    }
    /**
     * Will add repository if it does not exist and return the repository
     */
    function createRepository(connector, resourceType, identifier) {
        if (identifier === void 0) { identifier = 'id'; }
        var repository = new Repository_1.default(connector, resourceType, identifier);
        addRepository(repository);
        return repositories[repository.resourceType];
    }
    function getRepository(resourceType) {
        return repositories[resourceType] || null;
    }
    function getRepositories() {
        return repositories;
    }
    return {
        repositories: repositories,
        createRepository: createRepository,
        addRepository: addRepository,
        getRepository: getRepository,
        getRepositories: getRepositories,
    };
};
var repositoryManager = createRepositoryManager();
Object.freeze(repositoryManager);
/**
 * A Singleton pattern for RepositoryManager
 */
exports.default = repositoryManager;
