"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@hyral/core");
var relationshipGetType_1 = __importDefault(require("./Relationship/relationshipGetType"));
function guessRelationCardinality(relation) {
    return Array.isArray(relation.data) ? 'one-to-many' : 'many-to-one';
}
function transformResource(item) {
    return new core_1.Resource(item.id, item.type, null, null, item.meta);
}
function getResourcesFromData(data) {
    return Object.entries(data.relationships)
        .reduce(function (carry, _a) {
        var _b;
        var field = _a[0], relation = _a[1];
        if (!relation.data) {
            return carry;
        }
        var resources = Array.isArray(relation.data)
            ? relation.data.map(function (item) { return transformResource(item); })
            : transformResource(relation.data);
        return Object.assign(carry, (_b = {}, _b[field] = resources, _b));
    }, {});
}
function getRelationDefinitionFromData(data) {
    return Object.entries(data.relationships)
        .reduce(function (resourceRelationships, _a) {
        var _b;
        var field = _a[0], relation = _a[1];
        return Object.assign(resourceRelationships, (_b = {},
            _b[field] = {
                cardinality: guessRelationCardinality(relation),
                many: Array.isArray(relation.data),
                resource: relationshipGetType_1.default(relation),
            },
            _b));
    }, {});
}
/**
 * Normalizes a single JSON data object into a Hyral Resource
 */
function normalizeResource(data) {
    if (!data.relationships) {
        return new core_1.Resource(data.id, data.type, data.attributes, null, data.meta);
    }
    var resource = new core_1.Resource(data.id, data.type, Object.assign(data.attributes, getResourcesFromData(data)), null, data.meta || null);
    if (Object.keys(data.relationships).length > 0) {
        resource.relationships = getRelationDefinitionFromData(data);
    }
    return resource;
}
exports.default = normalizeResource;
